@@ -7,11 +7,18 @@ Created on Mon Apr 13 09:47:41 2020
 
 import matplotlib.pyplot as plt
 from matplotlib import cm
-import numpy as np
+import sys
+if sys.version_info[1]<8:
+    import pkg_resources
+    pkg_resources.require("numpy==1.15.0")
+    import numpy as np
+else: 
+    import numpy as np
 import pandas as pd
 from glob import glob
 import sklearn.mixture
 import xml.etree.ElementTree as ET
+import tables
 from PIL import Image, ImageDraw, ImageFont
 import re
 from pathlib import Path
